'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var all = require('it-all');
var error = require('ipfs-message-port-protocol/error');
var cid = require('ipfs-message-port-protocol/cid');
var block = require('ipfs-message-port-protocol/block');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var all__default = /*#__PURE__*/_interopDefaultLegacy(all);

class BlockService {
  constructor(ipfs) {
    this.ipfs = ipfs;
  }
  async get(query) {
    const cid$1 = cid.decodeCID(query.cid);
    const block$1 = await this.ipfs.block.get(cid$1, query);
    const transfer = new Set();
    return {
      transfer,
      block: block.encodeBlock(block$1, transfer)
    };
  }
  async put(query) {
    const input = query.block;
    const result = await this.ipfs.block.put(input, query);
    const transfer = new Set();
    return {
      transfer,
      cid: cid.encodeCID(result, transfer)
    };
  }
  async rm(query) {
    const transfer = new Set();
    const result = await all__default["default"](this.ipfs.block.rm(query.cids.map(cid.decodeCID), query));
    return result.map(entry => encodeRmEntry(entry, transfer));
  }
  async stat(query) {
    const cid$1 = cid.decodeCID(query.cid);
    const result = await this.ipfs.block.stat(cid$1, query);
    return {
      ...result,
      cid: cid.encodeCID(result.cid)
    };
  }
}
const encodeRmEntry = (entry, transfer) => {
  const cid$1 = cid.encodeCID(entry.cid, transfer);
  if (entry.error) {
    return {
      cid: cid$1,
      error: error.encodeError(entry.error)
    };
  } else {
    return { cid: cid$1 };
  }
};

exports.BlockService = BlockService;
