'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var cid = require('ipfs-message-port-protocol/cid');
var dag = require('ipfs-message-port-protocol/dag');

class DAGService {
  constructor(ipfs) {
    this.ipfs = ipfs;
  }
  async put(query) {
    const dagNode = dag.decodeNode(query.dagNode);
    const cid$1 = await this.ipfs.dag.put(dagNode, query);
    return cid.encodeCID(cid$1);
  }
  async get(query) {
    const {cid: cid$1, path, localResolve, timeout, signal} = query;
    const {value, remainderPath} = await this.ipfs.dag.get(cid.decodeCID(cid$1), {
      path,
      localResolve,
      timeout,
      signal
    });
    const transfer = new Set();
    return {
      remainderPath,
      value: dag.encodeNode(value, transfer),
      transfer
    };
  }
  async resolve(query) {
    const {cid: cid$1, remainderPath} = await this.ipfs.dag.resolve(decodePathOrCID(query.cid), query);
    return {
      cid: cid.encodeCID(cid$1),
      remainderPath
    };
  }
}
const decodePathOrCID = input => {
  if (typeof input === 'string') {
    return input;
  } else {
    return cid.decodeCID(input);
  }
};

exports.DAGService = DAGService;
