import {
  encodeCID,
  decodeCID
} from 'ipfs-message-port-protocol/cid';
import {
  decodeNode,
  encodeNode
} from 'ipfs-message-port-protocol/dag';
export class DAGService {
  constructor(ipfs) {
    this.ipfs = ipfs;
  }
  async put(query) {
    const dagNode = decodeNode(query.dagNode);
    const cid = await this.ipfs.dag.put(dagNode, query);
    return encodeCID(cid);
  }
  async get(query) {
    const {cid, path, localResolve, timeout, signal} = query;
    const {value, remainderPath} = await this.ipfs.dag.get(decodeCID(cid), {
      path,
      localResolve,
      timeout,
      signal
    });
    const transfer = new Set();
    return {
      remainderPath,
      value: encodeNode(value, transfer),
      transfer
    };
  }
  async resolve(query) {
    const {cid, remainderPath} = await this.ipfs.dag.resolve(decodePathOrCID(query.cid), query);
    return {
      cid: encodeCID(cid),
      remainderPath
    };
  }
}
const decodePathOrCID = input => {
  if (typeof input === 'string') {
    return input;
  } else {
    return decodeCID(input);
  }
};